@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,10 +27,15 @@ require_once dirname(__FILE__).'/js/configuration.triggers.edit.js.php';
 
 $triggersWidget = (new CWidget())
 	->setTitle(_('Trigger prototypes'))
-	->addItem(get_header_host_table('triggers', $data['hostid'], $data['parent_discoveryid']));
+	->setNavigation(getHostNavigation('triggers', $data['hostid'], $data['parent_discoveryid']));
+
+$url = (new CUrl('trigger_prototypes.php'))
+	->setArgument('context', $data['context'])
+	->getUrl();
 
 // create form
-$triggersForm = (new CForm())
+$triggersForm = (new CForm('post', $url))
+	->setId('triggers-prototype-form')
 	->setName('triggersForm')
 	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE)
 	->addVar('form', $data['form'])
@@ -68,6 +73,13 @@ $triggersFormList
 			->setAriaRequired()
 			->setAttribute('autofocus', 'autofocus')
 	)
+	->addRow(
+		(new CLabel(_('Event name'), 'event_name')),
+		(new CTextAreaFlexible('event_name', $data['event_name']))
+			->setReadonly($data['limited'])
+			->setMaxlength(DB::getFieldLength('triggers', 'event_name'))
+			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+	)
 	->addRow(
 		new CLabel(_('Operational data'), 'opdata'),
 		(new CTextBox('opdata', $data['opdata'], $data['limited']))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
@@ -523,10 +535,9 @@ $triggersFormList
 	)
 	->addRow(_('Create enabled'), (new CCheckBox('status'))->setChecked($status))
 	->addRow(_('Discover'),
-		(new CRadioButtonList('discover', (int) $data['discover']))
-			->addValue(_('Yes'), ZBX_PROTOTYPE_DISCOVER)
-			->addValue(_('No'), ZBX_PROTOTYPE_NO_DISCOVER)
-			->setModern(true)
+		(new CCheckBox('discover', ZBX_PROTOTYPE_DISCOVER))
+			->setChecked($data['discover'] == ZBX_PROTOTYPE_DISCOVER)
+			->setUncheckedValue(ZBX_PROTOTYPE_NO_DISCOVER)
 	);
 
 // append tabs to form
@@ -538,17 +549,19 @@ $triggersTab->addTab('triggersTab',	_('Trigger prototype'), $triggersFormList);
 
 // tags
 $triggersTab->addTab('tags-tab', _('Tags'), new CPartial('configuration.tags.tab', [
-	'source' => 'trigger_prototype',
-	'tags' => $data['tags'],
-	'show_inherited_tags' => $data['show_inherited_tags'],
-	'readonly' => false
-]));
+		'source' => 'trigger_prototype',
+		'tags' => $data['tags'],
+		'show_inherited_tags' => $data['show_inherited_tags'],
+		'readonly' => false
+	]), TAB_INDICATOR_TAGS
+);
 
 /*
  * Dependencies tab
  */
 $dependenciesFormList = new CFormList('dependenciesFormList');
 $dependenciesTable = (new CTable())
+	->setId('dependency-table')
 	->setAttribute('style', 'width: 100%;')
 	->setHeader([_('Name'), _('Action')]);
 
@@ -561,13 +574,20 @@ foreach ($data['db_dependencies'] as $dependency) {
 
 	if ($dependency['flags'] == ZBX_FLAG_DISCOVERY_PROTOTYPE) {
 		$description = (new CLink($depTriggerDescription,
-			'trigger_prototypes.php?form=update'.url_param('parent_discoveryid').'&triggerid='.$dependency['triggerid']
-		))->setAttribute('target', '_blank');
+			(new CUrl('trigger_prototypes.php'))
+				->setArgument('form', 'update')
+				->setArgument('parent_discoveryid', $data['parent_discoveryid'])
+				->setArgument('triggerid', $dependency['triggerid'])
+				->setArgument('context', $data['context'])
+		))->setTarget('_blank');
 	}
 	elseif ($dependency['flags'] == ZBX_FLAG_DISCOVERY_NORMAL) {
 		$description = (new CLink($depTriggerDescription,
-			'triggers.php?form=update&triggerid='.$dependency['triggerid']
-		))->setAttribute('target', '_blank');
+			(new CUrl('triggers.php'))
+				->setArgument('form', 'update')
+				->setArgument('triggerid', $dependency['triggerid'])
+				->setArgument('context', $data['context'])
+		))->setTarget('_blank');
 	}
 
 	$row = new CRow([$description,
@@ -617,12 +637,12 @@ $dependenciesFormList->addRow(_('Dependencies'),
 		->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
 		->setAttribute('style', 'min-width: '.ZBX_TEXTAREA_BIG_WIDTH.'px;')
 );
-$triggersTab->addTab('dependenciesTab', _('Dependencies'), $dependenciesFormList);
+$triggersTab->addTab('dependenciesTab', _('Dependencies'), $dependenciesFormList, TAB_INDICATOR_DEPENDENCY);
 
 // append buttons to form
 if (!empty($data['triggerid'])) {
 	$deleteButton = new CButtonDelete(_('Delete trigger prototype?'),
-		url_params(['form', 'triggerid', 'parent_discoveryid'])
+		url_params(['form', 'triggerid', 'parent_discoveryid', 'context']), 'context'
 	);
 
 	if ($data['limited']) {
@@ -633,14 +653,14 @@ if (!empty($data['triggerid'])) {
 		new CSubmit('update', _('Update')), [
 			new CSubmit('clone', _('Clone')),
 			$deleteButton,
-			new CButtonCancel(url_param('parent_discoveryid'))
+			new CButtonCancel(url_params(['parent_discoveryid', 'context']))
 		]
 	));
 }
 else {
 	$triggersTab->setFooter(makeFormFooter(
 		new CSubmit('add', _('Add')),
-		[new CButtonCancel(url_param('parent_discoveryid'))]
+		[new CButtonCancel(url_params(['parent_discoveryid', 'context']))]
 	));
 }
 
